@@ -1,6 +1,6 @@
-import warnings
+from IPython.display import display
 
-from pyrecorder.converters.matpotlib import Matplotlib
+from pyrecorder.converters.matplotlib import Matplotlib
 
 
 class Video:
@@ -17,8 +17,8 @@ class Video:
         if not (isinstance(self.rec, list) or isinstance(self.rec, tuple)):
             self.rec = [self.rec]
 
-    def record(self):
-        img = self.converter.do()
+    def record(self, **kwargs):
+        img = self.converter.do(**kwargs)
         self.converter.finalize()
 
         for r in self.rec:
@@ -28,6 +28,12 @@ class Video:
         for r in self.rec:
             r.close()
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, tb):
+        self.close()
+
     @classmethod
     def from_iteratable(cls, video, iteratable, func=None, **kwargs):
         for entry in iteratable:
@@ -42,14 +48,22 @@ class Video:
         video.close()
 
 
-def load(fname, height="500px"):
+def load(fname):
     if fname.endswith("gif"):
         from IPython.display import Image
         return Image(filename=fname)
 
     elif fname.endswith("mp4"):
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-            from IPython.display import HTML
-            code = f"<iframe height='{height}' width='100%' src='{fname}' frameborder='0' allowfullscreen></iframe>"
-            return HTML(code)
+        from IPython.display import HTML
+        html = """
+        <div align="middle">
+            <video controls>
+            <source src="%s" type="video/mp4">
+        </video>
+        </div>
+        """
+        return display(HTML(data=html % fname))
+
+    elif fname.endswith("html"):
+        from IPython.display import HTML
+        return HTML(filename=fname)
